summaryrefslogtreecommitdiff
path: root/plugins/recaptcha/recaptcha.php
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/recaptcha/recaptcha.php')
-rw-r--r--plugins/recaptcha/recaptcha.php8
1 files changed, 4 insertions, 4 deletions
diff --git a/plugins/recaptcha/recaptcha.php b/plugins/recaptcha/recaptcha.php
index 38a860fc7..94cf0ccd1 100644
--- a/plugins/recaptcha/recaptcha.php
+++ b/plugins/recaptcha/recaptcha.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Plugin to show reCaptcha when a user registers
*
@@ -20,14 +20,14 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Plugin
- * @package Laconica
+ * @package StatusNet
* @author Eric Helgeson <erichelgeson@gmail.com>
* @copyright 2009
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) {
+if (!defined('STATUSNET') && !defined('LACONICA')) {
exit(1);
}
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Plugin to show reCaptcha when a user registers